constraint_to_row: Constraint to row

View source: R/create_matrices.R

constraint_to_rowR Documentation

Constraint to row

Description

Evaluate a constraint, which has been formatted as an equation, with all terms moved to the left hand side, and return a single row of a (in)equality constraint matrix.

Usage

constraint_to_row(varnames, hyp)

Arguments

hyp

Character. An (in)equality constraint formatted as equation, with all terms on the left hand side.

Value

Numeric vector.


bain documentation built on Aug. 24, 2026, 5:10 p.m.